#region File Description
//-----------------------------------------------------------------------------
// TowerDescriptionScreen.cs
// Defines the tower description screen.  Will display information such as fire rate, and range
//  about the current selected tower.  
//
// Authors: John Karczewski, Kelsey Schlarman
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using SpriteSheetRuntime;
using System;
#endregion

namespace ZuneDefense
{
    /// <summary>
    /// The pause menu comes up over the top of the game,
    /// giving the player options to resume or quit.
    /// </summary>
    class TowerDescriptionScreen : MenuScreen
    {
        #region Initialization

        GameBoard board;
        Tower tower;
        Vector2 cursorPosition;
        GameScreen screen;

        /// <summary>
        /// Constructor.
        /// </summary>
        public TowerDescriptionScreen()
            : base("")
        {}

        public TowerDescriptionScreen(Vector2 cursorPosition, GameBoard board, Tower tower, GameScreen screen)
            : base("")
        {
            this.board = board;
            this.cursorPosition = cursorPosition;

            this.tower = tower;
            this.screen = screen;

            // Flag that there is no need for the game to transition
            // off when the pause menu is on top of it.
            IsPopup = true;
        }


        #endregion

        #region Handle Input
        public override void HandleInput(InputState input)
        {
            if (input.SelectButtonClicked())
            {
                if (tower.Cost <= GameplayScreen.player1.Gold)
                {
                    GameplayScreen.player1.takeMoney(tower.Cost);
                    board.SpawnTower(tower);
                    ScreenManager.RemoveScreen(screen);
                    ExitScreen();
                }
            }
            else if (input.CancelButtonClicked())
            {
                ExitScreen();
            }
        }


        /// <summary>
        /// Event handler for when the user selects ok on the "are you sure
        /// you want to quit" message box. This uses the loading screen to
        /// transition from the game back to the main menu screen.
        /// </summary>
        void ConfirmQuitMessageBoxAccepted(object sender, PlayerIndexEventArgs e)
        {
            LoadingScreen.Load(ScreenManager, false, null, new BackgroundScreen(),
                                                           new MainMenuScreen());
        }


        #endregion

        #region Draw


        /// <summary>
        /// Draws the pause menu screen. This darkens down the gameplay screen
        /// that is underneath us, and then chains to the base MenuScreen.Draw.
        /// </summary>
        public override void Draw(GameTime gameTime)
        {
            SpriteSheet spriteSheet = ScreenManager.SpriteSheet;
            SpriteBatch spriteBatch = ScreenManager.SpriteBatch;
            SpriteFont font = ScreenManager.Font;
            SpriteFont titleFont = ScreenManager.TitleFont;

            spriteBatch.Begin(SpriteBlendMode.AlphaBlend, SpriteSortMode.Deferred, SaveStateMode.None);

            // Draw background.
            Rectangle sourceRectangle;
            if (tower.Cost <= GameplayScreen.player1.Gold)
            {
                sourceRectangle = spriteSheet.SourceRectangle(spriteSheet.GetIndex("TowerDescriptionBackground"));
            }
            else 
                sourceRectangle = spriteSheet.SourceRectangle(spriteSheet.GetIndex("TowerDescriptionBackgroundNoEnter"));


            Rectangle boundingRectangle = new Rectangle(0, 0, sourceRectangle.Width, sourceRectangle.Height);
            spriteBatch.Draw(spriteSheet.Texture, boundingRectangle, sourceRectangle, Color.White);

            // Draw tower image, but make sure we get the right section of the sprite.
            sourceRectangle = spriteSheet.SourceRectangle(tower.TextureIndex);
            sourceRectangle.Width = tower.Width;
            sourceRectangle.Height = tower.Height;
            sourceRectangle.Offset((int)DrawableZuneDefenseComponent.SpriteDirection.Right * tower.Width, 0);
            boundingRectangle = new Rectangle(100, 80, tower.Width, tower.Height);
            spriteBatch.Draw(spriteSheet.Texture, boundingRectangle, sourceRectangle, Color.White);

            // Draw the menu title.
            string title = tower.Name;
            Vector2 titlePosition = new Vector2(ZuneDefenseGame.Width / 2, 50);
            Vector2 titleOrigin = titleFont.MeasureString(title) / 2;
            titleOrigin.X = (float)Math.Round(titleOrigin.X);
            titleOrigin.Y = (float)Math.Round(titleOrigin.Y);
            Color titleColor = new Color(0, 0, 0, TransitionAlpha);

            spriteBatch.DrawString(titleFont, title, titlePosition, titleColor, 0,
                                   titleOrigin, 1, SpriteEffects.None, 0);

            //Draw cost
            string cost_value = System.Convert.ToString(tower.Cost);
            string cost = "Cost: " + cost_value;
            Vector2 costPosition = new Vector2(30, 140);
            Vector2 costOrigin = new Vector2(0,0);
            Color costColor = new Color(0, 0, 0, TransitionAlpha);

            if (tower.Cost > GameplayScreen.player1.Gold)
            {
                costColor = new Color(255, 0, 0, TransitionAlpha);
            }

            float costScale = .90f;

            spriteBatch.DrawString(font, cost, costPosition, costColor, 0,
                                   costOrigin, costScale, SpriteEffects.None, 0);

            //Draw range
            string range_value = System.Convert.ToString(tower.Range);
            string range = "Range: " + range_value;
            Vector2 rangePosition = new Vector2(140, 170);
            Vector2 rangeOrigin = new Vector2(0, 0);
            Color rangeColor = new Color(0, 0, 0, TransitionAlpha);
            float rangeScale = .90f;

            spriteBatch.DrawString(font, range, rangePosition, rangeColor, 0,
                                   rangeOrigin, rangeScale, SpriteEffects.None, 0);

            //Draw damage
            string damage_value = System.Convert.ToString(tower.Damage);
            string damage = "Damage: " + damage_value;
            Vector2 damagePosition = new Vector2(20, 170);
            Vector2 damageOrigin = new Vector2(0, 0);
            Color damageColor = new Color(0, 0, 0, TransitionAlpha);
            float damageScale = .90f;

            spriteBatch.DrawString(font, damage, damagePosition, damageColor, 0,
                                   damageOrigin, damageScale, SpriteEffects.None, 0);

            //Draw fire rate
            string rate_value = System.Convert.ToString(tower.FireRate);
            string rate = "Fire Rate: " + rate_value;
            Vector2 ratePosition = new Vector2(120, 140);
            Vector2 rateOrigin = new Vector2(0, 0);
            Color rateColor = new Color(0, 0, 0, TransitionAlpha);
            float rateScale = .90f;

            spriteBatch.DrawString(font, rate, ratePosition, rateColor, 0,
                                   rateOrigin, rateScale, SpriteEffects.None, 0);


            //Draw description
            string description = tower.Description;
            Vector2 descriptionPosition = new Vector2(10, 210);
            Vector2 descriptionOrigin = new Vector2(0, 0);
            Color descriptionColor = new Color(0, 0, 0, TransitionAlpha);
            float descriptionScale = 1.00f;

            spriteBatch.DrawString(font, description, descriptionPosition, descriptionColor, 0,
                                   descriptionOrigin, descriptionScale, SpriteEffects.None, 0);

            spriteBatch.End();

            base.Draw(gameTime);
        }


        #endregion
    }
}
